@@ -113,7 +113,9 @@ done:
 
 send_data:
   if (get_data && !orig_ret) {
-    CGI_PutStr(s, bl.c_str(), len);
+    int r = CGI_PutStr(s, bl.c_str(), len);
+    if (r < 0)
+      return r;
   }
 
   return 0;
